==> picom_8.2.orig.tar.gz: picom-8.2/.github/issue_template.md <==
<!-- The template below is for reporting bugs. For feature requests and others, feel free to delete irrelevant entries. -->

### Platform
<!-- Example: Ubuntu Desktop 17.04 amd64 -->

### GPU, drivers, and screen setup
<!--
    Example: NVidia GTX 670, nvidia-drivers 381.09, two monitors configured side-by-side with xrandr
    Please include the version of the video drivers (xf86-video-*) and mesa.
    Please also paste the output of `glxinfo -B` here.
 -->

### Environment
<!-- Tell us something about the desktop environment you are using, for example: i3-gaps, Gnome Shell, etc. -->

### picom version
<!-- Put the output of `compton --version` or `picom --version` here. -->
<!-- If you are running compton v4 or later, please also include the output of `compton --diagnostics` or `picom --diagnostics` -->
<!-- Example: v1 -->

### Configuration:
```
// Paste your configuration here
```

### Steps of reproduction
<!--
    If you can reliably reproduce this bug, please describe the quickest way to do so
    This information will greatly help us diagnosing and fixing the issue.
 -->

1.
2.

### Expected behavior

### Current Behavior

### Stack trace
<!--
    If the compositor crashes, please make sure you built it with debug info, and provide a stack trace captured when it crashed.
    Note, when the compositor crashes in a debugger, your screen might look frozen. But gdb will likely still handle your input if it is focused.
    Often you can use 'bt' and press enter to get the stack trace, then 'q', enter, 'y', enter to quit gdb.
 -->

<!-- Or, you can enable core dump, and upload the core file with the corresponding executable here. -->

### Other details
<!-- If your problem is visual, you are encouraged to record a short video when the problem occurs and link to it here. -->

==> picom_10.2.orig.tar.gz: picom-10.2/.github/issue_template.md <==
<!-- The template below is for reporting bugs. For feature requests and others, feel free to delete irrelevant entries. -->

### Platform
<!-- Example: Ubuntu Desktop 17.04 amd64 -->

### GPU, drivers, and screen setup
<!--
    Example: NVidia GTX 670, nvidia-drivers 381.09, two monitors configured side-by-side with xrandr
    Please include the version of the video drivers (xf86-video-*) and mesa.
    Please also paste the output of `glxinfo -B` here.
 -->

### Environment
<!-- Tell us something about the desktop environment you are using, for example: i3-gaps, Gnome Shell, etc. -->

### picom version
<!-- Put the output of `picom --version` here. -->
<!-- Example: v8.2 -->
<details>
<summary>Diagnostics</summary>

<!-- Please also include the output of `picom --diagnostics` -->
</details>

### Configuration:
<details>
    <summary>Configuration file</summary>

```
// Paste your configuration here
```
</details>

### Steps of reproduction
<!--
    If you can reliably reproduce this bug, please describe the quickest way to do so
    This information will greatly help us diagnosing and fixing the issue.
 -->

1.
2.

### Expected behavior

### Current Behavior

### Stack trace
<!--
    If the compositor crashes, please make sure you built it with debug info, and provide a stack trace captured when it crashed.
    Note, when the compositor crashes in a debugger, your screen might look frozen. But gdb will likely still handle your input if it is focused.
    Often you can use 'bt' and press enter to get the stack trace, then 'q', enter, 'y', enter to quit gdb.
 -->

<!-- Or, you can enable core dump, and upload the core file with the corresponding executable here. -->

### OpenGL trace
<!--
    If you encounter visual glitches, i.e. things don't look how they supposed to look. It might be a good idea to follow the steps here:
    https://github.com/yshui/picom/wiki/Reporting-issues#capture-a-trace , and upload the resulting trace here.
-->

### Other details
<!-- If your problem is visual, you are encouraged to record a short video when the problem occurs and link to it here. -->
